@@ -1,7 +1,7 @@
 #sem:name: Web document
 #sem:tip: Generates a simple html document with a stylesheet
 
-# Thomas Nagy, 2007 (ita)
+# Thomas Nagy, 2007-2015
 
 # exclude
 # caption
@@ -32,10 +32,10 @@ cwd = os.getcwd()
 os.chdir(sembind.get_var('temp_dir'))
 pics = {} # map the id to the picture
 lst = os.listdir('.')
-for i in lst:
-	if i.rfind('pic-') > -1:
-		pics[ i.replace('pic-', '').split('.')[0] ] = i
-		shutil.copy2(i, outdir)
+for x in lst:
+	if x.startswith('diag-') and not x.endswith('pdf'):
+		pics[ x.replace('diag-', '').split('.')[0] ] = x
+		shutil.copy2(x, outdir)
 os.chdir(cwd)
 
 buf = []
