@@ -1,10 +1,9 @@
 #sem:name: PDF LaTeX
 #sem:tip: Generates a LaTeX project for obtaining PDF files
 
-# Thomas Nagy, 2007 (ita)
-import os, time, shutil, re, StringIO
-from sgmllib import SGMLParser
-import htmlentitydefs
+# Thomas Nagy, 2007-2015
+
+import os, time, shutil, re, StringIO, getpass
 
 # Additional variables:
 # exclude   1
@@ -14,8 +13,9 @@ settings = {
 'doc_content':'',
 'doc_class':'article',
 
-'header_off':'None',
-'footer_off':'None',
+'all_latex':False,
+'header_off':'',
+'footer_off':'',
 'header_l':'',
 'header_c':'',
 'header_r':'',
@@ -29,7 +29,7 @@ settings = {
 'doc_date':'',
 'doc_date_off':'None',
 
-'doc_author':'',
+'doc_author':getpass.getuser(),
 'doc_author_off':'None',
 
 'babel':'english', # frenchb
@@ -61,64 +61,17 @@ cwd = os.getcwd()
 os.chdir(sembind.get_var('temp_dir'))
 pics = {} # map the id to the picture
 lst = os.listdir('.')
-for i in lst:
-	if -1 == i.rfind('pic-'): continue
-	pics[ i.replace('pic-', '').split('.')[0] ] = i
-	shutil.copy2(i, outdir)
+for x in lst:
+	if x.startswith('diag-'):
+		key = x.split('.')[0].replace('diag-', '')
+		if x.endswith('.pdf') or not key in pics:
+			pics[key] = x
+		shutil.copy2(x, outdir)
 os.chdir(cwd)
 
 buf = []
 out = buf.append
 
-class TrucProcessor(SGMLParser):
-	def reset(self):
-		self.pieces = []
-		self.state = ""
-		self.buf = ""
-		self.inli = 0
-		SGMLParser.reset(self)
-
-	def unknown_starttag(self, tag, attrs):
-		if tag == 'ul':
-			if self.inli and self.buf:
-				self.pieces.append('\\item ')
-				self.pieces.append(tex_convert(self.buf))
-				self.pieces.append('\n')
-			self.pieces.append('\\begin{itemize}\n')
-
-		if tag == 'li':
-			self.inli += 1
-
-		self.buf = ""
-
-	def unknown_endtag(self, tag):
-		if tag == 'p':
-			self.pieces.append(tex_convert(self.buf))
-			self.pieces.append('\n')
-		elif tag == 'li':
-			if self.buf:
-				self.pieces.append('\\item ')
-				self.pieces.append(tex_convert(self.buf))
-				self.pieces.append('\n')
-			self.inli -= 1
-		elif tag == 'ul':
-			self.pieces.append('\\end{itemize}\n')
-
-	def handle_charref(self, ref):
-		self.pieces.append("&#%(ref)s;" % locals())
-
-	def handle_data(self, text):
-		self.buf = text
-
-	def output(self):
-		return "".join(self.pieces)
-
-def parse_string(s):
-	parser = TrucProcessor()
-	parser.feed(s)
-	parser.close()
-	return parser.output()
-
 def print_nodes(node, niv):
 	sm = tex_convert(node.get_val('summary'))
 	if settings['doc_class'] in ['book', 'report']:
@@ -188,6 +141,8 @@ def print_nodes(node, niv):
 				w = int(node.get_val('pic_w'))
 				restrict = ""
 				if (w > 5*72): restrict = "[width=5in]"
+			if not restrict:
+				restrict = "[width=\\textwidth,height=\\textheight,keepaspectratio]"
 
 			out('\\begin{figure}[htbp]\n')
 			out('  \\begin{center}\n')
@@ -232,6 +187,13 @@ shutil.copy2(template_dir()+'/pdflatex/wscript', outdir+'/wscript')
 shutil.copy2(template_dir()+'/waf', outdir+'/waf')
 os.chmod(outdir+'/waf', 0755)
 
+f = open(outdir + '/run.sh', 'w')
+try:
+	f.write('#! /bin/sh\npython2 waf configure build --view\n')
+finally:
+	f.close()
+os.chmod(outdir + '/run.sh', 0755)
+
 # load the preview on main.tex
 visualize('pdflatex', outdir+'/main.tex')
 
